lib

package
v0.0.0-...-d46b61a Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 9, 2019 License: MIT Imports: 11 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AddCrashers

func AddCrashers(crashers, name, commit string) (bool, error)

AddCrashers adds the crashers to the git repository.

func BinaryPath

func BinaryPath(workdir string) string

BinaryPath returns the file path to the fuzzing binary based on the temporary directory.

func BuildBinary

func BuildBinary(target conf.Target, workdir string, stop <-chan struct{}) (string, error)

BuildBinary builds the fuzzing binary and returns the path.

func CommitHash

func CommitHash(dir string) (string, error)

CommitHash gets the commit hash of the local git repository.

func CopyCrashers

func CopyCrashers(workdir, target string) error

CopyCrashers copies the crashers from the workdir to the target directory.

func PkgDir

func PkgDir(pkg string) (string, error)

PkgDir returns the absolute path to a go package.

func RunBinary

func RunBinary(fuzzBin string, workdir string, stop <-chan struct{}) error

RunBinary runs the fuzzing binary until the stop channel is closed.

func SetupCorpus

func SetupCorpus(corpus, workdir string) error

SetupCorpus sets up the temporary working directory with the configured corpus.

func SetupTempWorkdir

func SetupTempWorkdir(targetName, commit string) (string, error)

SetupTempWorkdir sets up the temporary working directory and returns the path.

func TempWorkdir

func TempWorkdir(targetName string, commit string) string

TempWorkdir returns the temporary workdir path for a given target and commit.

Types

This section is empty.

Jump to