Documentation
¶
Index ¶
- func AddCrashers(crashers, name, commit string) (bool, error)
- func BinaryPath(workdir string) string
- func BuildBinary(target conf.Target, workdir string, stop <-chan struct{}) (string, error)
- func CommitHash(dir string) (string, error)
- func CopyCrashers(workdir, target string) error
- func PkgDir(pkg string) (string, error)
- func RunBinary(fuzzBin string, workdir string, stop <-chan struct{}) error
- func SetupCorpus(corpus, workdir string) error
- func SetupTempWorkdir(targetName, commit string) (string, error)
- func TempWorkdir(targetName string, commit string) string
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AddCrashers ¶
AddCrashers adds the crashers to the git repository.
func BinaryPath ¶
BinaryPath returns the file path to the fuzzing binary based on the temporary directory.
func BuildBinary ¶
BuildBinary builds the fuzzing binary and returns the path.
func CommitHash ¶
CommitHash gets the commit hash of the local git repository.
func CopyCrashers ¶
CopyCrashers copies the crashers from the workdir to the target directory.
func SetupCorpus ¶
SetupCorpus sets up the temporary working directory with the configured corpus.
func SetupTempWorkdir ¶
SetupTempWorkdir sets up the temporary working directory and returns the path.
func TempWorkdir ¶
TempWorkdir returns the temporary workdir path for a given target and commit.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.